/*
 * MZTalk - a small and simple talk program
 *
 * Copyright 2004 Marcello Zaniboni
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package marcellozaniboni;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JEditorPane;
import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JViewport;

/**
 * Provides a GUI for formatted help.
 *  
 * @author Marcello Zaniboni
 */
public class HelpDialog {

	private String title = null;
	private String resURI = null;
	private String iconResource = null;
	
	/**
	 * Constructor.
	 * 
	 * @param windowTitle - The title of the window.
	 * @param resource - The String representing the URL to open.
	 * @param windowIcon - The String representing the URL for the icon of the JFrame.
	 */
	public HelpDialog(String windowTitle, String resource, String windowIcon) {
		this.title = windowTitle;
		this.resURI = resource;
		this.buildGUI();
		this.iconResource = windowIcon;
	}

	private void buildGUI() {
		final JFrame frame = new JFrame(title);
		if (iconResource != null && !(iconResource.trim().equals("")))
			frame.setIconImage(new ImageIcon(this.getClass().getResource(TalkManager.APP_ICON)).getImage());
		final JButton btnQuit = new JButton("Close");

		JEditorPane html;
		class HelpExitListener implements ActionListener {
			public void actionPerformed(ActionEvent e){
				frame.hide();
			}
		}
		btnQuit.addActionListener(new HelpExitListener ());

		try {
			URL url = null; 
			try { 
				url = this.getClass().getResource(resURI);
			} catch (Exception e) { 
				System.err.println("Failed to open " + resURI); 
				url = null; 
			} 
			Box vbox = Box.createVerticalBox();
			if(url != null) {
				html = new JEditorPane(url);
				html.setEditable(false);
				JScrollPane scroller = new JScrollPane();
				JViewport vp = scroller.getViewport();
				vp.add(html);
				//vbox.add(vp);
				vbox.add(scroller);
				vbox.add(Box.createRigidArea(new Dimension(5, 5)));
				Box hbox = Box.createHorizontalBox();
				hbox.add(Box.createHorizontalGlue());
				hbox.add(btnQuit);
				hbox.add(Box.createHorizontalGlue());
				vbox.add(hbox);
				vbox.add(Box.createRigidArea(new Dimension(5, 5)));
				frame.getContentPane().add(vbox);
			}
		} catch (MalformedURLException e) {
			System.err.println("Malformed URL: " + e);
		} catch (IOException e) {
			System.err.println("IOException: " + e);
		}
		frame.pack();
		frame.setSize(600,400);
		frame.setLocation(60, 50);
		frame.setResizable(false);
		frame.setVisible(true);
	}

}
