/*
 * MZTalk - a small and simple talk program
 *
 * Copyright 2004 Marcello Zaniboni
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package marcellozaniboni;

import java.awt.Component;
import java.io.BufferedReader;

import javax.swing.JOptionPane;

public class TalkReceiver extends Thread {

	private BufferedReader in = null;
	private ITalkUI gui = null;
	TalkManager talkmanager = null;

	public TalkReceiver(ITalkUI ui, BufferedReader bufferedreader, TalkManager tm) {
		gui = ui;
		in = bufferedreader;
		talkmanager = tm;
	}

	public void run() {
		String key = talkmanager.getKey();
		System.out.println("receiver thread started");
		String msgToPrint = null;
		String previousMsg = "";

		try {
			final String closeMessage = TalkKeyGen.encode(TalkManager.CLOSE_MESSAGE, key);
			while (!(msgToPrint = in.readLine()).endsWith(closeMessage)) {
				if ((!msgToPrint.equals(previousMsg)) && (!msgToPrint.equals(""))) {
					gui.putMessage(TalkKeyGen.decode(msgToPrint, key));
					previousMsg = msgToPrint;
				} else {
					try {
						Thread.sleep(TalkManager.RECEIVER_REFRESH);
					} catch (Throwable t) {
						t.printStackTrace(System.err);
					}
				}
			}
			JOptionPane.showInternalMessageDialog((Component)gui, "Connection closed.",
				TalkManager.APP_TITLE, JOptionPane.INFORMATION_MESSAGE);
			System.exit(0);
		} catch (NullPointerException npe) {
			// do nothing (it happens while closing the app)
		} catch (Throwable t) {
			t.printStackTrace(System.err);
		}
		talkmanager.destroy();
	}
}
