/*
 * MZTalk - a small and simple talk program
 *
 * Copyright 2004 Marcello Zaniboni
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package marcellozaniboni;

import java.io.PrintWriter;

public class TalkSender extends Thread {
	
	private PrintWriter out = null;
	private ITalkUI gui = null;
	TalkManager talkmanager = null;
	
	public TalkSender(ITalkUI ui, PrintWriter printwriter, TalkManager tm) {
		gui = ui;
		out = printwriter;
		talkmanager = tm;
	}
	
	public void run() {
		String key = talkmanager.getKey();
		System.out.println("sender thread started");
		String msgToSend = null;
		String previousMsg = "";		
		final String closeMessage = TalkKeyGen.encode(TalkManager.CLOSE_MESSAGE, key);
		while (!(previousMsg.endsWith(closeMessage))) {
			if (gui.readyToSend()) {
				msgToSend = gui.getMessage();
				if (!(msgToSend.equals(""))) {
					out.println(TalkKeyGen.encode(talkmanager.getSignature() + msgToSend, key));
					out.flush();
					previousMsg = msgToSend;
				}
			} else {
				try {
					Thread.sleep(TalkManager.SENDER_REFRESH);
				} catch (Throwable t) {
					t.printStackTrace(System.err);
				}
			}
		}
		talkmanager.destroy();
	}
}
